@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2020-2021 Tobias Leupold <tl at stonemx dot de>
+// SPDX-FileCopyrightText: 2020-2022 Tobias Leupold <tl at stonemx dot de>
 //
 // SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -27,7 +27,7 @@ public:
     const QTimeZone &imagesTimeZone() const;
     bool setImagesTimeZone(const QByteArray &id);
 
-signals:
+Q_SIGNALS:
     void imagesTimeZoneChanged();
     void cameraDriftSettingsChanged();
 
