@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2020-2021 Tobias Leupold <tl at stonemx dot de>
+// SPDX-FileCopyrightText: 2020-2022 Tobias Leupold <tl at stonemx dot de>
 //
 // SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -45,7 +45,7 @@ public:
     void centerCoordinates(const Coordinates &coordinates);
     Coordinates currentCenter() const;
 
-signals:
+Q_SIGNALS:
     void mapMoved(const Coordinates &center);
     void imagesDropped(const QVector<QString> &paths);
     void requestLoadGpx(const QVector<QString> &paths);
@@ -54,7 +54,7 @@ protected:
     void dragEnterEvent(QDragEnterEvent *event) override;
     void dropEvent(QDropEvent *event) override;
 
-private slots:
+private Q_SLOTS:
     void showContextMenu(int x, int y);
     void changeFloaterVisiblity(QAction *action);
 
