@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2020-2021 Tobias Leupold <tl at stonemx dot de>
+// SPDX-FileCopyrightText: 2020-2022 Tobias Leupold <tl at stonemx dot de>
 //
 // SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -26,13 +26,13 @@ class SettingsDialog : public QDialog
 public:
     explicit SettingsDialog(Settings *settings, QWidget *parent);
 
-signals:
+Q_SIGNALS:
     void imagesListsModeChanged();
 
 protected:
     void accept() override;
 
-private slots:
+private Q_SLOTS:
     void setTrackColor();
 
 private: // Functions
@@ -62,6 +62,7 @@ private: // Variables
     QComboBox *m_elevationDataset;
 
     QComboBox *m_writeMode;
+    QCheckBox *m_allowWriteRawFiles;
     QCheckBox *m_createBackups;
 
 };
